@@ -67,7 +67,12 @@ get.nodenames<-function(newick.txt)
 {
 	nnames = character(0)
 	ttmp = newick.txt
-	nname.pat="(\\(|,|\\))([a-zA-Z0-9']{1,})(:|;)"
+	
+	if(grepl("^.*;$",ttmp)) {
+		# remove trailing semi-colon, otherwise it will mess up the regular expression matching
+		ttmp = substring(ttmp,first=1,last=(nchar(ttmp)-1))
+	}
+	nname.pat="(\\(|,|\\))([a-zA-Z0-9'_\\.]{1,})(:|;)"
 	junk = regexpr(nname.pat,ttmp)
 	count = 0
 	while(junk[1] != -1)
@@ -1646,6 +1651,7 @@ addSubNode <- function(x,anc,dec,position,dataf,pos.is.fraction=FALSE)
 	} else {
 		
 
+
 		newdf = getEmptyDataFrame(x,stringsAsFactors=FALSE)  # ??
 
 		# special case (if lengths are the same, then assume that they are in order):
